| SelectionBias-package | R Documentation |
Computes bounds and sensitivity parameters as part of sensitivity analysis for selection bias. Different bounds are provided: the SV (Smith and VanderWeele), sharp bounds, AF (assumption-free) bound, GAF (generalized AF), and CAF (counterfactual AF) bounds. The calculation of the sensitivity parameters for the SV, sharp, and GAF bounds assume an additional dependence structure in form of a generalized M-structure. The bounds can be calculated for any structure as long as the necessary assumptions hold. See Smith and VanderWeele (2019) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1097/EDE.0000000000001032")}, Zetterstrom, Sjölander, and Waernabum (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/09622802251374168")}, Zetterstrom and Waernbaum (2022) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1515/em-2022-0108")}, and Zetterstrom (2024) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1515/em-2023-0033")}.
Maintainer: Stina Zetterstrom stina.zetterstrom@gmail.com (ORCID)
Authors:
Ingeborg Waernbaum (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.